/* ----------------------------------------
 * Origin  : GFI INFORMATIQUE 
 * Project : CDPP Propagation Tool 
 * ----------------------------------------
 * History 
 * Version : 17/11/2017 : SCA : V2.2.2
 *  Creation
 * Version : 25/11/2022 : LBE : V2.6
 * DM-ID : Redmine#10630 : AMDA zoom type
 * Version : 12/09/2023 : LBE : V2.8
 * DM-ID : Redmine#10629 : 12/09/2023 : SEP plot improvments
 * Version : 25/11/2024 : LBE : V2.11
 * DM-ID : Redmine#11104 : 25/11/2024 : VDA module added
 * ----------------------------------------
 */
package fr.tlse.irap.pt.client.controller.tools.plot;

import fr.tlse.irap.pt.client.controller.tools.plot.SpectroPlotComponent.ESEPPlotTool;

public interface ISpectroPlotMenu {

    public void runShowEnergy(int pIdx);

    public void runShowAllEnergies();

    public void runShowSpectro(ESEPPlotTool pTool);

    public void runClickPoints();

    public void runClickPointsFile();

    public void runRemoveLastPoint();

    public void runSavePoints();

    public void runFitPoints();

    public void runSetZoom();

    public void runResetZoom();
}
